<?php

/*
 * This file is part of the TaskManagementBundle for Kimai 2.
 * All rights reserved by Kevin Papst (www.kevinpapst.de).
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace KimaiPlugin\TaskManagementBundle\EventSubscriber;

use App\Constants;
use App\Event\DashboardEvent;
use App\Widget\Type\CompoundRow;
use KimaiPlugin\TaskManagementBundle\Widget\PendingTasksWidget;
use KimaiPlugin\TaskManagementBundle\Widget\UserTasksWidget;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\Security\Core\Authorization\AuthorizationCheckerInterface;

final class DashboardSubscriber implements EventSubscriberInterface
{
    /**
     * @var AuthorizationCheckerInterface
     */
    private $security;
    /**
     * @var UserTasksWidget
     */
    private $user;
    /**
     * @var PendingTasksWidget
     */
    private $pending;

    public function __construct(AuthorizationCheckerInterface $security, UserTasksWidget $userWidget, PendingTasksWidget $pendingWidget)
    {
        $this->security = $security;
        $this->user = $userWidget;
        $this->pending = $pendingWidget;
    }

    /**
     * @return array
     */
    public static function getSubscribedEvents(): array
    {
        return [
            DashboardEvent::class => ['onDashboardEvent', 100],
        ];
    }

    /**
     * @param DashboardEvent $event
     */
    public function onDashboardEvent(DashboardEvent $event)
    {
        if (!$this->security->isGranted('task_start')) {
            return;
        }

        $section = new CompoundRow();
        $section->setOrder(12);
        $section->addWidget($this->user);

        if ($this->security->isGranted('task_assign')) {
            $section->addWidget($this->pending);
        }

        $event->addSection($section);
    }
}
