<?php

/*
 * This file is part of the TaskManagementBundle for Kimai 2.
 * All rights reserved by Kevin Papst (www.kevinpapst.de).
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace KimaiPlugin\TaskManagementBundle\Form;

use App\Form\Toolbar\AbstractToolbarForm;
use App\Form\Type\TeamType;
use KimaiPlugin\TaskManagementBundle\Form\Type\StatusType;
use KimaiPlugin\TaskManagementBundle\Repository\Query\TaskQuery;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;

class TaskToolbarForm extends AbstractToolbarForm
{
    /**
     * {@inheritdoc}
     */
    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        $this->addSearchTermInputField($builder);
        $this->addCustomerChoice($builder);
        $this->addProjectChoice($builder);
        $this->addActivityChoice($builder);

        if ($options['include_user']) {
            $this->addUsersChoice($builder);
        }

        if ($options['include_team']) {
            $builder->add('teams', TeamType::class, [
                'placeholder' => '',
                'multiple' => true,
                'required' => false,
                'teamlead_only' => false,
            ]);
        }
        $builder->add('status', StatusType::class, [
            'placeholder' => '',
            'multiple' => true,
            'required' => false,
        ]);

        $this->addPageSizeChoice($builder);
        $this->addHiddenPagination($builder);
        $this->addHiddenOrder($builder);
        $this->addHiddenOrderBy($builder, TaskQuery::TASKS_ORDER_ALLOWED);
    }

    /**
     * {@inheritdoc}
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'include_user' => false,
            'include_team' => false,
            'data_class' => TaskQuery::class,
            'csrf_protection' => false,
        ]);
    }
}
