# Task and todo-list management plugin for Kimai 2

A Kimai 2 plugin, which allows you to plan your work and distribute tasks among your users and teams.
It features two new dashboard widgets and a new "Task management" view in the left navigation.

You can test it in the ["Plugins" demo](https://www.kimai.org/demo/).

## Features

- Add "tasks" which are used to start and group timesheet records
- Each task consists of a 
  - Title
  - End date (optional)
  - Assigned user (optional: if left empty, the task can be chosen/self-assigned by allowed users)
  - Assigned team (optional: if given, only users from this team see this task and can assign it)
  - Customer (will be copied to the started timesheets)
  - Project (will be copied to the started timesheets)
  - Activity (will be copied to the started timesheets)
  - Description (will be copied to the started timesheets)

With the help of the dashboard widgets every user can manage their work. 

Or you configure the permissions in a way, that the user only see the "My times widget". 
A Teamlead can then prepare a list of tasks (working schedule) for the user, which ustilizes the widget to start/pause/stop 
the tasks. Either the user can close the task (if allowed) or you configure it, that only teamleads can close tasks 
from the admin view (after reviewing the work results).  

### My times widget

- Displays all tasks that:
    - are not "closed"
    - that are assigned to you

This widget features the following UI elements (if permissions are set for the user):
  - a checkbox to close the task (moving to status done will stop all related timesheet entries)
  - a title (colored "green" if end date is set but not yet reached, colored "red" if end date is overdue)
  - a Play/Pause button
  - an Edit button
  - an Unassign button (will stop all related timesheet entries and move the task to the "Pending tasks widget")
  - a Delete button (will remove the task entirely, but keep the related timesheet entries)
  - a Create button (create a new task for the currently logged-in user)      

### Pending tasks widget

- Displays all tasks that:
    - that are not assigned to a user
    - that are in "pending" status
    - that can be seen by the user (via team assignment or completely unassigned tasks)

This widget features the following UI elements (if permissions are set for the user):
  - a title (colored "green" if end date is set but not yet reached, colored "red" if end date is overdue)
  - an Edit button
  - an Assign button (move the task back to the "My times widget")
  - a Delete button (will remove the task entirely, but keep the related timesheet entries)
  - a Create button (create a new pending task)   

## Installation

This plugin is compatible with the following Kimai releases:

| Bundle version    | Kimai 2 version  |
|---                |---               |
| 1.0               | 1.7              |

### Copy the files 

Extract the ZIP file and upload the included directory and all files to your Kimai installation to the new directory:  
`var/plugins/TaskManagementBundle/`

The file structure needs to look like this afterwards:

```
var/plugins/
├── TaskManagementBundle
│   ├── TaskManagementBundle.php
|   └ ... more files and directories follow here ... 
```
### Rebuild the cache

After uploading the files, Kimai needs to know about the new plugin. It will be found, once the cache was re-built:

```
cd kimai2/
bin/console cache:clear --env=prod
bin/console cache:warmup --env=prod
```

### Install the bundle database

Run the following command:

```bash
bin/console kimai:bundle:tasks:install
```

This will install all required databases.

## Permissions

This bundle ships a couple of new permissions, which limit access to certain functionalities:

| Permission | Description |
|--- |--- |
| `task_edit_own` | Create and edit tasks that are assigned to the currently logged-in user. |
| `task_edit_other` | Allows to edit all tasks that are visible to the user. Create new unassigned tasks, assign team and user. |
| `task_assign` | Self-assign a pending task by the currently logged-in user. Required to see the "Pending tasks" widget on the dashboard. |
| `task_start` | Start a task. Only possible if task is assigned to the current user. Required to see the "My tasks" widget on the dashboard. |
| `task_close` | Close a task. Only possible if task is assigned to the current user. The task will be removed from the "My tasks" widget after it is reloaded (until then it could be reopened). |
| `task_delete` | Delete any existing task. |
| `task_view` | Gives access to the task administration |

Access to tasks for other users is also limited by the permission `view_other_timesheet`.
If a user has the `task_view` permission, but NOT `view_other_timesheet`, he will only see own tasks.

Please be aware, that the data for non-admin users is still limited by team assignments!

**This bundle ships a pre-configured permission set for all default user roles. You can adjust them in your "user role & permissions" administration.** 

## Updating the plugin

Updating the bundle works the same way as the installation does. 

- Delete the directory `var/plugins/TaskManagementBundle/`
- Execute all installation steps again:
  - Copy files
  - Clear cache
  - Update database with `bin/console kimai:bundle:tasks:install` 

## Screenshots

The overview page of all tasks:

![Screenshot](https://www.kimai.org/images/marketplace/tasks-screenshot.png)

The task widget:

![Screenshot](https://www.kimai.org/images/marketplace/tasks-widget.png)

When creating a new task, you can record the following fields:

![Screenshot](https://www.kimai.org/images/marketplace/tasks-create.png)

## Uninstall

- Delete the extension directory `var/plugins/TaskManagementBundle/`
- Remove the database tables ONLY if you don't want to keep the tasks data (create a backup first!):
```sql
DROP TABLE kimai2_tasks
DROP TABLE bundle_migration_tasks
```
- [Reload your cache](https://www.kimai.org/documentation/configurations.html) with the cache command
