<?php

/*
 * This file is part of the TaskManagementBundle for Kimai 2.
 * All rights reserved by Kevin Papst (www.kevinpapst.de).
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace KimaiPlugin\TaskManagementBundle\Repository\Loader;

use App\Entity\Project;
use App\Repository\Loader\LoaderInterface;
use Doctrine\ORM\EntityManagerInterface;
use KimaiPlugin\TaskManagementBundle\Entity\Task;

final class TaskIdLoader implements LoaderInterface
{
    /**
     * @var EntityManagerInterface
     */
    private $entityManager;

    public function __construct(EntityManagerInterface $entityManager)
    {
        $this->entityManager = $entityManager;
    }

    /**
     * @param int[] $ids
     */
    public function loadResults(array $ids): void
    {
        if (empty($ids)) {
            return;
        }

        $em = $this->entityManager;

        $qb = $em->createQueryBuilder();
        $projects = $qb->select('PARTIAL e.{id}', 'project')
            ->from(Task::class, 'e')
            ->leftJoin('e.project', 'project')
            ->andWhere($qb->expr()->in('e.id', $ids))
            ->getQuery()
            ->execute();

        if (!empty($projects)) {
            $projectIds = array_map(function (Task $task) {
                return $task->getProject()->getId();
            }, $projects);

            $qb = $em->createQueryBuilder();
            $qb->select('PARTIAL p.{id}', 'customer')
                ->from(Project::class, 'p')
                ->leftJoin('p.customer', 'customer')
                ->andWhere($qb->expr()->in('p.id', $projectIds))
                ->getQuery()
                ->execute();
        }

        $qb = $em->createQueryBuilder();
        $qb->select('PARTIAL e.{id}', 'activity')
            ->from(Task::class, 'e')
            ->leftJoin('e.activity', 'activity')
            ->andWhere($qb->expr()->in('e.id', $ids))
            ->getQuery()
            ->execute();

        $qb = $em->createQueryBuilder();
        $qb->select('PARTIAL e.{id}', 'user')
            ->from(Task::class, 'e')
            ->leftJoin('e.user', 'user')
            ->andWhere($qb->expr()->in('e.id', $ids))
            ->getQuery()
            ->execute();

        $qb = $em->createQueryBuilder();
        $qb->select('PARTIAL e.{id}', 'team')
            ->from(Task::class, 'e')
            ->leftJoin('e.team', 'team')
            ->andWhere($qb->expr()->in('e.id', $ids))
            ->getQuery()
            ->execute();

        $qb = $em->createQueryBuilder();
        $qb->select('PARTIAL e.{id}', 'timesheet')
            ->from(Task::class, 'e')
            ->leftJoin('e.timesheets', 'timesheet')
            ->andWhere($qb->expr()->in('e.id', $ids))
            ->getQuery()
            ->execute();
    }
}
