<?php

/*
 * This file is part of the TaskManagementBundle for Kimai 2.
 * All rights reserved by Kevin Papst (www.kevinpapst.de).
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace KimaiPlugin\TaskManagementBundle\Voter;

use App\Entity\User;
use App\Voter\AbstractVoter;
use KimaiPlugin\TaskManagementBundle\Entity\Task;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;

final class TaskVoter extends AbstractVoter
{
    /**
     * @var string[]
     */
    private $allowed = [
        'task_edit',
        'task_assign',
        'task_start',
        'task_close',
        'task_delete',
        'task_view',
    ];

    /**
     * @param string $attribute
     * @param mixed $subject
     * @return bool
     */
    protected function supports($attribute, $subject)
    {
        if ($subject instanceof Task && in_array($attribute, $this->allowed)) {
            return true;
        }

        return false;
    }

    /**
     * @param string $attribute
     * @param Task $subject
     * @param TokenInterface $token
     * @return bool
     */
    protected function voteOnAttribute($attribute, $subject, TokenInterface $token)
    {
        $user = $token->getUser();

        if (!$user instanceof User) {
            return false;
        }

        switch ($attribute) {
            case 'task_start':
            case 'task_close':
                if (null === $subject->getUser() || $subject->getUser()->getId() !== $user->getId()) {
                    return false;
                }
                break;

            case 'task_assign':
                if (null !== $subject->getUser() && $subject->getUser()->getId() !== $user->getId()) {
                    return false;
                }
                break;

            case 'task_edit':
                if (null !== $subject->getUser() && $subject->getUser()->getId() === $user->getId()) {
                    $attribute .= '_own';
                } else {
                    $attribute .= '_other';
                }
                break;
        }

        return $this->hasRolePermission($user, $attribute);
    }
}
