<?php

/*
 * This file is part of the TaskManagementBundle for Kimai 2.
 * All rights reserved by Kevin Papst (www.kevinpapst.de).
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace KimaiPlugin\TaskManagementBundle\Widget;

use App\Entity\User;
use App\Security\CurrentUser;
use App\Widget\Type\SimpleWidget;
use KimaiPlugin\TaskManagementBundle\Entity\Task;
use KimaiPlugin\TaskManagementBundle\Repository\Query\TaskQuery;
use KimaiPlugin\TaskManagementBundle\Repository\TaskRepository;

class UserTasksWidget extends SimpleWidget
{
    /**
     * @var TaskRepository
     */
    protected $repository;

    public function __construct(TaskRepository $repository, CurrentUser $user)
    {
        $this->repository = $repository;
        $this->setId('UserTasksWidget');
        $this->setTitle('My tasks');
        $this->setOptions([
            'user' => $user->getUser(),
            'page' => 1,
            'pageSize' => 5,
            'id' => '',
        ]);
    }

    public function getOptions(array $options = []): array
    {
        $options = parent::getOptions($options);

        if (empty($options['id'])) {
            $options['id'] = uniqid('UserTasksWidget_');
        }

        return $options;
    }

    public static function createQuery(User $user, $page, int $pageSize = 5): TaskQuery
    {
        $query = new TaskQuery();
        $query->setUser($user);
        $query->setPageSize($pageSize);
        $query->setPage($page);
        $query->setStatus([Task::STATUS_PENDING, Task::STATUS_IN_PROGRESS]);
        $query->setBegin(new \DateTime('now', new \DateTimeZone($user->getTimezone())));

        return $query;
    }

    public function getData(array $options = [])
    {
        $options = $this->getOptions($options);

        $query = self::createQuery($options['user'], $options['page'], $options['pageSize']);

        return $this->repository->getPagerfantaForQuery($query);
    }

    public function getTemplateName(): string
    {
        return '@TaskManagement/widget-user-tasks.html.twig';
    }
}
